diff mbox

mac80211: Fix scan_ies_len to include DS Params

Message ID 20101027104033.GA8305@jm.kir.nu (mailing list archive)
State Not Applicable, archived
Headers show

Commit Message

Jouni Malinen Oct. 27, 2010, 10:40 a.m. UTC
None
diff mbox

Patch

--- uml.orig/net/mac80211/main.c	2010-10-27 12:56:39.000000000 +0300
+++ uml/net/mac80211/main.c	2010-10-27 12:58:32.000000000 +0300
@@ -677,10 +677,11 @@  int ieee80211_register_hw(struct ieee802
 	/*
 	 * Calculate scan IE length -- we need this to alloc
 	 * memory and to subtract from the driver limit. It
 	 * includes the (extended) supported rates and HT
 	 * information -- SSID is the driver's responsibility.
 	 */
-	local->scan_ies_len = 4 + max_bitrates; /* (ext) supp rates */
+	local->scan_ies_len = 4 + max_bitrates /* (ext) supp rates */ +
+		3 /* DS Params */;
 	if (supp_ht)
 		local->scan_ies_len += 2 + sizeof(struct ieee80211_ht_cap);
@@ -677,10 +677,11 @@  int ieee80211_register_hw(struct ieee802
 	 * Calculate scan IE length -- we need this to alloc
 	 * memory and to subtract from the driver limit. It
-	 * includes the (extended) supported rates and HT
+	 * includes the DS Params, (extended) supported rates, and HT
 	 * information -- SSID is the driver's responsibility.
 	 */